#include <X11/Xlib.h>
#include <algorithm>
#include <iostream>
#include <vector>
#include <cmath>
using namespace std;

struct vec2{int x; int y;};

vector<vec2> convex_hull(vector<vec2> const &polygon){
  vector<vec2> h1,h2;
  for (auto i: polygon){
    while (h1.size()>=2 and (i.y-h1[h1.size()-1].y)*(h1[h1.size()-1].x-h1[h1.size()-2].x)-(i.x-h1[h1.size()-1].x)*(h1[h1.size()-1].y-h1[h1.size()-2].y)<=0) h1.pop_back();
    while (h2.size()>=2 and (i.y-h2[h2.size()-1].y)*(h2[h2.size()-1].x-h2[h2.size()-2].x)-(i.x-h2[h2.size()-1].x)*(h2[h2.size()-1].y-h2[h2.size()-2].y)>=0) h2.pop_back();
    h1.push_back(i);
    h2.push_back(i);
  }
  h1.insert(h1.end(),h2.rbegin()+1,h2.rend()-1);
  return h1;
}

long double diameter(vector<vec2> p){
  p=convex_hull(p);
  long double res=1e9L;
  for (int a=0,b=1; a<p.size(); a++){
    for (int c=(b+1)%p.size();; b=c, (++c)%=p.size())
      if (hypotl(p[c].x-p[a].x,p[c].y-p[a].y)
        >=hypotl(p[b].x-p[a].x,p[b].y-p[a].y)) b=c; else break;
    res=min(res,hypotl(p[b].x-p[a].x,p[b].y-p[a].y));
  }
  return res;
}

int main(){
  vector<vec2> polygon;

  Display* dpy;
  Window root,win;
  XEvent ev; GC gc;
  int screen;

  dpy=XOpenDisplay(NULL);
  screen=DefaultScreen(dpy);
  root=RootWindow(dpy,screen);
  win=
  XCreateSimpleWindow(dpy,root,1,1,512,512,0,BlackPixel(dpy,screen),BlackPixel(dpy,screen));
  XStoreName(dpy,win,"Output");gc=
  XCreateGC(dpy,win,0,NULL);
  XSetForeground(dpy,gc,WhitePixel(dpy,screen));
  XSelectInput(dpy,win,ExposureMask|ButtonPressMask);
  XMapWindow(dpy,win);

  auto WM_DELETE_WINDOW = XInternAtom(dpy,"WM_DELETE_WINDOW",false);
  XSetWMProtocols(dpy,win,&WM_DELETE_WINDOW,1);

  bool done=0;
  while (!done){
    XNextEvent(dpy,&ev);
    switch (ev.type){
      case Expose:{
        for (int i=0,j=polygon.size()-1; i<polygon.size(); j=i++){
          if (i!=j) XDrawLine(dpy,win,gc,polygon[j].x,polygon[j].y,polygon[i].x,polygon[i].y);
          XDrawArc(dpy,win,gc,polygon[i].x-4,polygon[i].y-4,8,8,0,360<<6);
        }
        break;
      }
      case ButtonPress:{
        XButtonPressedEvent &button=*(XButtonPressedEvent*)&ev;
        polygon.push_back({button.x,button.y});
        XClearArea(dpy,win,0,0,512,512,true);
//        done=1;
        break;
      }
      case ClientMessage:{
        done=1;
        break;
      }
      default:{
        break;
      }
    }
  }

  XUnmapWindow(dpy,win);
  XDestroyWindow(dpy,win);

  // cout<<diameter(polygon)/2.L<<endl;
  cout<<polygon.size()<<endl;
  for (auto i: polygon)
    cout<<i.x<<" "<<-i.y<<endl;
}
