#include <unordered_map>/*{{{*/
#include <algorithm>
#include <iostream>
#include <fstream>
#include <sstream>
#include <cassert>
#include <string>
#include <vector>
#include <stack>
#include <map>
#include <set>
/*}}}*/

enum JudgeCode:int{
  judge_error=1,
  correct=42,
  wrong_answer=43,
};

struct Range{/*{{{*/
  int weight;
  int strength;
};/*}}}*/

std::vector<Range> read_cranes(std::istream &in){/*{{{*/
  int n; in>>n;
  std::vector<Range> cranes(n);
  for (auto &i: cranes){
    in>>i.weight>>i.strength;
  }
  return cranes;
}/*}}}*/

std::vector<int> read_buildings(std::istream &in){/*{{{*/
  int n; in>>n;
  std::vector<int> buildings(n);
  for (auto &i: buildings){
    in>>i;
  }
  return buildings;
}/*}}}*/

bool is_impossible(std::string s){
  std::transform(s.begin(), s.end(), s.begin(), ::tolower);
  return s=="impossible";
}

int main(int argc, char **argv){
  using namespace std;

  if (argc<3){
    cerr<<"usage: "<<argv[0]<<" testcase.in testcase.ans [feedback_dir] < team.out"<<endl;
    return judge_error;
  }else if (argc<4){
    cerr<<"writing feedback to stdout"<<endl;
  }else{
    if (argc>4){
      cerr<<"warning: ignoring "<<argc-4<<" extra arguments"<<endl;
    }
    cerr<<"writing feedback to "<<argv[3]<<"/judgemessage.txt"<<endl;
    if (not freopen((string(argv[3]) + "/judgemessage.txt").c_str(), "a", stdout)){
      cerr<<"unable to open feedback file"<<endl;
      return judge_error;
    }
  }

  ifstream canonical_input(argv[1]);
  ifstream canonical_output(argv[2]);
  auto &team_output = cin;

  // Read cranes and buildings from input file.
  auto const cranes = read_cranes(canonical_input);
  auto const buildings = read_buildings(canonical_input);

  // Check if official answer is "impossible".
  {
    string canonical_answer;
    if ((canonical_output>>canonical_answer) and is_impossible(canonical_answer)){
      string team_answer;
      if ((team_output>>team_answer) and is_impossible(team_answer)){
        cout<<"OK case is impossible"<<endl;
        return correct;
      }else{
        cout<<"Team did not output impossible"<<endl;
        return wrong_answer;
      }
    }
  }

  // Set of cranes used by the team solution. Used for checking duplicates.
  set<int> cranes_used;

  // Read team answer.
  for (auto const &building : buildings) {
    string team_line;
    if (not getline(team_output, team_line)){
      cout<<"Team output finished too early"<<endl;
      return wrong_answer;
    }
    if (is_impossible(team_line)){
      cout<<"Team output impossible but judge answer is possible"<<endl;
      return wrong_answer;
    }
    stringstream sst(team_line);

    // cerr<<"Reading answer for building "<<building<<endl;
    int team_strength=0;
    for (int x; sst>>x;){
      // cerr<<" Team crane: "<<x<<endl;
      if (x<1 or x>cranes.size()){
        cout<<"Team output invalid crane "<<x<<endl;
        return wrong_answer;
      }
      if (not cranes_used.insert(x).second){
        cout<<"Team used crane "<<x<<" more than once"<<endl;
        return wrong_answer;
      }
      if (cranes[x-1].weight>team_strength){
        cout<<"Team tried to use crane "<<x<<" with current strength "<<team_strength<<endl;
        return wrong_answer;
      }
      team_strength=max(team_strength,cranes[x-1].strength);
    }

    if (team_strength<building){
      cout<<"Team did not output a sequence strong enough for "<<building<<endl;
      return wrong_answer;
    }
  }

  // Looks good. Ship it.
  cout<<"OK team used "<<cranes_used.size()<<" / "<<cranes.size()<<" cranes"<<endl;
  return correct;
}
