#include <unordered_map>/*{{{*/
#include <algorithm>
#include <iostream>
#include <fstream>
#include <sstream>
#include <cassert>
#include <string>
#include <vector>
#include <stack>
#include <map>
using namespace std;/*}}}*/

enum JudgeCode:int{
  judge_error=1,
  correct=42,
  wrong_answer=43,
};

constexpr size_t max_answer_size=10000;

string simulate(string word,vector<pair<int,int>> const &swaps){
  for (auto &i: swaps){
    if (word[i.second-1]<word[i.first-1]){
      swap(word[i.second-1],word[i.first-1]);
    }
  }
  return word;
}

int main(int argc, char **argv){
  if (argc<3){
    cerr<<"usage: "<<argv[0]<<" testcase.in testcase.ans [feedback_dir] < team.out"<<endl;
    return judge_error;
  }else if (argc<4){
    cerr<<"writing feedback to stdout"<<endl;
  }else{
    if (argc>4){
      cerr<<"warning: ignoring "<<argc-4<<" extra arguments"<<endl;
    }
    cerr<<"writing feedback to "<<argv[3]<<"/judgemessage.txt"<<endl;
    if (not freopen((string(argv[3]) + "/judgemessage.txt").c_str(), "a", stdout)){
      cerr<<"unable to open feedback file"<<endl;
      return judge_error;
    }
  }

  ifstream canonical_input(argv[1]);
  ifstream canonical_output(argv[2]);
  auto &team_output = cin;

  string goal_word; assert(canonical_input>>goal_word);

  // Read team answer
  vector<pair<int,int>> team_answer;
  while (team_answer.size()<=max_answer_size){
    pair<int,int> op;
    if (not (cin>>op.first>>op.second)){
      break;
    }
    if (op.first<=0 or op.first>goal_word.length()
        or op.second<=0 or op.second>goal_word.length()){
      cout<<"Bad output: swap "<<op.first<<" "<<op.second<<" is out of bounds [1-"<<goal_word.length()<<"]"<<endl;
      return wrong_answer;
    }
    team_answer.emplace_back(op);
  }

  // Validate output size.
  if (team_answer.size()>max_answer_size){
    cout<<"Bad output: team gave more than "<<max_answer_size<<" operations"<<endl;
    return wrong_answer;
  }

  // Test team answer using simulation.
  {
    string word=goal_word;
    sort(word.begin(),word.end());

    string got=simulate(word,team_answer);
    if (got!=goal_word){
      cout<<"wrong answer for input: "<<word<<endl;
      cout<<"     got: "<<got<<endl;
      cout<<"expected: "<<goal_word<<endl;
      cout<<"          ";
      for (int i=0; i<got.length(); i++){
        cout<<(got[i]==goal_word[i]?' ':'^');
      }
      cout<<endl;
      return wrong_answer;
    }
  }

  cout<<"OK "<<team_answer.size()<<" swaps for "<<goal_word.length()<<" letters"<<endl;
  return correct;
}
