#include <unordered_map>/*{{{*/
#include <algorithm>
#include <iostream>
#include <fstream>
#include <sstream>
#include <cassert>
#include <locale>
#include <vector>
#include <string>
#include <vector>
#include <stack>
#include <map>
using namespace std;/*}}}*/

enum JudgeCode:int{
  judge_error=1,
  correct=42,
  wrong_answer=43,
};

constexpr size_t max_answer_size=7000;

struct vec3{
  int x,y,z;

  bool operator==(vec3 const &a)const{return x==a.x and y==a.y and z==a.z;}
  bool operator!=(vec3 const &a)const{return x!=a.x or y!=a.y or z!=a.z;}
  vec3 operator-(vec3 const &a)const{return {x-a.x,y-a.y,z-a.z};}
  int man()const{return abs(x)+abs(y)+abs(z);}

  friend ostream& operator<<(ostream& s, vec3 const &v){
    return s<<"("<<v.x<<","<<v.y<<","<<v.z<<")";
  }
};

static class PunctuationIgnorer: public ctype<char>{
  private:
    static const mask *make_mask(){
      static vector<mask> m(classic_table(),classic_table()+table_size);
      for (auto i: ",.(){}[]\t "){
        m[i]=space;
      }
      return &m[0];
    }
  public:
    PunctuationIgnorer(size_t refs=0): ctype(make_mask(),false,refs){}
} punc;

int main(int argc, char **argv){
  if (argc<3){
    cerr<<"usage: "<<argv[0]<<" testcase.in testcase.ans [feedback_dir] < team.out"<<endl;
    return judge_error;
  }else if (argc<4){
    cerr<<"writing feedback to stdout"<<endl;
  }else{
    if (argc>4){
      cerr<<"warning: ignoring "<<argc-4<<" extra arguments"<<endl;
    }
    cerr<<"writing feedback to "<<argv[3]<<"/judgemessage.txt"<<endl;
    if (not freopen((string(argv[3]) + "/judgemessage.txt").c_str(), "a", stdout)){
      cerr<<"unable to open feedback file"<<endl;
      return judge_error;
    }
  }

  ifstream canonical_input(argv[1]);
  ifstream canonical_output(argv[2]);
  auto &team_output = cin;

  // Ignore punctuation in the team's output.
  team_output.imbue(locale(team_output.getloc(),&punc));

  pair<vec3,vec3> start,finish;
  assert(canonical_input
      >>start.first.x>>start.first.y>>start.first.z
      >>finish.first.x>>finish.first.y>>finish.first.z);
  assert(canonical_input
      >>start.second.x>>start.second.y>>start.second.z
      >>finish.second.x>>finish.second.y>>finish.second.z);

  // Read team answer.
  vector<pair<vec3,vec3>> team_answer;
  while (team_answer.size()<=max_answer_size){
    pair<vec3,vec3> state;
    if (not (team_output>>state.first.x>>state.first.y>>state.first.z)){
      break;
    }
    if (not (team_output>>state.second.x>>state.second.y>>state.second.z)){
      break;
    }
    team_answer.emplace_back(state);
  }

  // Validate output size.
  if (team_answer.size()>max_answer_size){
    cout<<"Team gave more than "<<max_answer_size<<" lines"<<endl;
    return wrong_answer;
  }
  if (team_answer.size()==0){
    cout<<"Team didn't write any lines"<<endl;
    return wrong_answer;
  }

  // Check output endpoints.
  if (team_answer.front().first!=start.first or team_answer.front().second!=start.second){
    cout<<"Team starting points don't match input"<<endl;
    return wrong_answer;
  }
  if (team_answer.back().first!=finish.first or team_answer.back().second!=finish.second){
    cout<<"Team ending points don't match input"<<endl;
    return wrong_answer;
  }

  // Check validity of moves
  for (size_t i=1; i<team_answer.size(); i++){
    if ((team_answer[i].first-team_answer[i-1].first).man()>1){
      cout<<"Team move "<<i<<" "
          <<team_answer[i-1].first<<" -> "<<team_answer[i].first
          <<" with first robot is illegal (too large)"<<endl;
      return wrong_answer;
    }
    if ((team_answer[i].second-team_answer[i-1].second).man()>1){
      cout<<"Team move "<<i<<" "
          <<team_answer[i-1].second<<" -> "<<team_answer[i].second
          <<" with second robot is illegal (too large)"<<endl;
      return wrong_answer;
    }

    if (team_answer[i].first==team_answer[i-1].second and
        team_answer[i].second==team_answer[i-1].first){
      cout<<"Robots swapped places on move "<<i<<endl;
      return wrong_answer;
    }
    if (team_answer[i].first==team_answer[i].second){
      cout<<"Robots are in the same place after move "<<i<<endl;
      return wrong_answer;
    }
  }

  cout<<"OK "<<team_answer.size()-1<<" moves"<<endl;
  return correct;
}
