#include <unordered_map>/*{{{*/
#include <algorithm>
#include <iostream>
#include <fstream>
#include <sstream>
#include <cassert>
#include <string>
#include <vector>
#include <stack>
#include <map>
using namespace std;/*}}}*/

enum JudgeCode:int{
  judge_error=1,
  correct=42,
  wrong_answer=43,
};

struct Person{
  int min_distance;
  int position;
};

bool is_impossible(std::string s){
  std::transform(s.begin(), s.end(), s.begin(), ::tolower);
  return s=="impossible";
}

int main(int argc, char **argv){
  if (argc<3){
    cerr<<"usage: "<<argv[0]<<" testcase.in testcase.ans < team.out"<<endl;
    return judge_error;
  }
  else if (argc>3){
    cerr<<"warning: ignoring "<<argc-3<<" extra arguments"<<endl;
  }

  // Standard boilerplate- get input, answer, and output
  ifstream canonical_input(argv[1]);
  ifstream canonical_output(argv[2]);
  auto &team_output = cin;

  // Special case for official output being "impossible";
  string first_token; assert(canonical_output>>first_token);
  if (is_impossible(first_token)){
    string team_token; team_output>>team_token;

    if (is_impossible(team_token)){
      cout<<"OK case is impossible"<<endl;
      return correct;
    }
    else{
      cout<<"Bad answer: case is impossible but team output starts with '"<<team_token<<"'"<<endl;
      return wrong_answer;
    }
  }

  // Read official input.
  int max_distance; assert(canonical_input>>max_distance);

  int vertices; assert(canonical_input>>vertices);
  vector<int64_t> v(vertices);
  for (int i=0; i<vertices; i++){
    assert(canonical_input>>v[i]);
  }

  int people; assert(canonical_input>>people);
  vector<Person> p(people);
  for (int i=0; i<people; i++){
    assert(canonical_input>>p[i].min_distance>>p[i].position);
    --p[i].position;
  }

  // Read team output.
  for (int to_move,step=1; team_output>>to_move; ++step){
    if (to_move<=0 or to_move>people){
      cout<<"Person "<<to_move<<" is not in range [1,"<<people<<"]"<<endl;
      return wrong_answer;
    }
    --to_move;

    ++p[to_move].position;

    if (p[to_move].position>=vertices){
      cout<<"Person "<<to_move+1<<" walked off the end of the route at step "<<step<<endl;
      return wrong_answer;
    }

    if (to_move>0 and v[p[to_move].position] - v[p[to_move-1].position] > max_distance){
      cout<<"Persons ("<<to_move
          <<", "<<to_move+1<<")"
          <<" at "<<v[p[to_move-1].position]<<", "<<v[p[to_move].position]
          <<" are too far apart (>"<<max_distance<<")"
          <<" at step "<<step<<endl;
      return wrong_answer;
    }
    if (to_move+1<people
        and p[to_move+1].position+1 < vertices
        and (v[p[to_move+1].position] - v[p[to_move].position])
            < (max(p[to_move+1].min_distance, p[to_move].min_distance))){
      cout<<"Persons ("<<to_move+1
          << ", "<<to_move+2<<")"
          <<" at "<<v[p[to_move].position]<<", "<<v[p[to_move+1].position]
          <<" are too close together (<"<<max(p[to_move+1].min_distance, p[to_move].min_distance)<<")"
          <<" at step "<<step<<endl;
      return wrong_answer;
    }
  }

  int total_finished=0;
  for (int i=0; i<people; i++){
    total_finished+=(p[i].position+1==vertices);
  }
  if (total_finished < people){
    cout<<"Bad answer: only "<<total_finished<<" / "<<people<<" finished the hike"<<endl;
    return wrong_answer;
  }
  else{
    cout<<"OK everyone finished"<<endl;
    if (is_impossible(first_token)){
      cout<<"But judge solution says impossible?"<<endl;
      return judge_error;
    }
    return correct;
  }
}
