#include <unordered_map>/*{{{*/
#include <algorithm>
#include <iostream>
#include <fstream>
#include <sstream>
#include <cassert>
#include <string>
#include <vector>
#include <stack>
#include <map>
using namespace std;/*}}}*/

constexpr int64_t broken=-1;
constexpr int64_t impossible=-2;

enum JudgeCode:int{
  judge_error=1,
  correct=42,
  wrong_answer=43,
};

template <class IFS>
int64_t get_answer(IFS &fout, map<int,int> students, map<int,pair<int,int>> rooms){
  int64_t res=0;
  vector<string> tokens;
  for (string token; fout>>token;){
    transform(token.begin(), token.end(), token.begin(), ::tolower);
    tokens.push_back(token);
  }

  if (tokens.size()==1 and tokens[0]=="impossible"){
    return impossible;
  }

  if (tokens.size()!=students.size()){
    if (tokens.size()<students.size()){
      cout<<"Too few tokens in output: expected "<<students.size()
          <<" got "<<tokens.size()<<endl;
      return broken;
    }else{
      cerr<<"Warning: too many tokens in output: expected "<<students.size()
          <<" got "<<tokens.size()<<endl;
    }
  }

  int idx=0;
  for (auto const &i: students){
    int j;
    {
      stringstream iss(tokens[idx++]);
      if (!(iss>>j)){
        cout<<"Failed to read "<<idx<<"-th integer"<<endl;
        return broken;
      }
    }
    if (not rooms.count(j)){
      cout<<"Invalid output: room "<<j<<" does not exist or was already used before "
            "class "<<i.first<<endl;
      return broken;
    }
    if (rooms[j].first<i.second){
      cout<<"Invalid output: room "<<j<<" fits "<<rooms[j].first<<" people "
            "but class "<<i.first<<" has "<<i.second<<" students"<<endl;
      return broken;
    }
    res+=rooms[j].second;
    rooms.erase(j);
  }
  return res;
}

int main(int argc, char **argv){
  if (argc<3){
    cerr<<"usage: "<<argv[0]<<" testcase.in testcase.ans < team.out"<<endl;
    return judge_error;
  }
  else if (argc>3){
    cerr<<"warning: ignoring "<<argc-3<<" extra arguments"<<endl;
  }

  // Standard boilerplate- get input, answer, and output
  ifstream canonical_input(argv[1]);
  ifstream canonical_output(argv[2]);
  auto &team_output = cin;

  int n,m; assert(canonical_input>>n>>m);
  map<int,int> students;
  map<int,pair<int,int>> rooms;
  for (int i=1; i<=n; i++) assert(canonical_input>>students[i]); // Population
  for (int i=1; i<=m; i++) assert(canonical_input>>rooms[i].first); // Capacity
  for (int i=1; i<=m; i++) assert(canonical_input>>rooms[i].second); // Rent

  // Read official output
  auto const expect=get_answer(canonical_output,students,rooms);
  if (expect==broken){
    cout<<"Failed to validate expected output, stopping"<<endl;
    return judge_error;
  }

  // Read official input
  auto const actual=get_answer(team_output,students,rooms);
  if (actual==broken){
    cout<<"Failed to validate team output, stopping"<<endl;
    return wrong_answer;
  }

  // Is it correct?
  if (actual==expect){
    return correct;
  }

  // If not, why not?
  if (actual==impossible or expect==impossible){
    if (actual!=impossible){
      cout<<"Bad testdata: got "<<actual<<" but case is supposed to be impossible"<<endl;
      return judge_error;
    }
    else{
      cout<<"Bad answer: got IMPOSSIBLE but answer is "<<expect<<endl;
      return wrong_answer;
    }
  }
  else if (actual<expect){
    cout<<"Bad testdata: got "<<actual<<" which is better than "<<expect<<endl;
    return judge_error;
  }
  else{
    cout<<"Wrong answer: got "<<actual<<" but expected "<<expect<<endl;
    return wrong_answer;
  }
}
